@@ -6,7 +6,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 http://osmcode.org/osmium
 
-Copyright (C) 2013-2015  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2016  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 class CommandCat : public Command, public with_multiple_osm_inputs, public with_osm_output {
 
-    osmium::osm_entity_bits::type m_osm_entity_bits = osmium::osm_entity_bits::all;
+    void setup_header(osmium::io::Header& header) const;
 
 public:
 
@@ -45,10 +45,12 @@ public:
 
     bool run() override final;
 
-    void setup_header(osmium::io::Header& header) const;
+    const char* name() const noexcept override final {
+        return "cat";
+    }
 
-    osmium::osm_entity_bits::type osm_entity_bits() const {
-        return m_osm_entity_bits;
+    const char* synopsis() const noexcept override final {
+        return "osmium cat [OPTIONS] OSM-FILE...";
     }
 
 }; // class CommandCat
