@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 http://osmcode.org/osmium
 
-Copyright (C) 2013-2015  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2016  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -33,8 +33,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "exception.hpp"
 
 bool CommandChangesetFilter::setup(const std::vector<std::string>& arguments) {
-    po::options_description cmdline("Allowed options");
-    cmdline.add_options()
+    po::options_description opts_cmd{"COMMAND OPTIONS"};
+    opts_cmd.add_options()
     ("with-discussion,d", "Changesets with discussions (comments)")
     ("without-discussion,D", "Changesets without discussions (no comments)")
     ("with-changes,c", "Changesets with changes")
@@ -47,26 +47,29 @@ bool CommandChangesetFilter::setup(const std::vector<std::string>& arguments) {
     ("before,b", po::value<std::string>(), "Changesets closed before this time")
     ;
 
-    add_common_options(cmdline);
-    add_single_input_options(cmdline);
-    add_output_options(cmdline);
+    po::options_description opts_common{add_common_options()};
+    po::options_description opts_input{add_single_input_options()};
+    po::options_description opts_output{add_output_options()};
 
-    po::options_description hidden("Hidden options");
+    po::options_description hidden;
     hidden.add_options()
     ("input-filename", po::value<std::string>(), "OSM input file")
     ;
 
-    po::options_description desc("Allowed options");
-    desc.add(cmdline).add(hidden);
+    po::options_description desc;
+    desc.add(opts_cmd).add(opts_common).add(opts_input).add(opts_output);
+
+    po::options_description parsed_options;
+    parsed_options.add(desc).add(hidden);
 
     po::positional_options_description positional;
     positional.add("input-filename", 1);
 
     po::variables_map vm;
-    po::store(po::command_line_parser(arguments).options(desc).positional(positional).run(), vm);
+    po::store(po::command_line_parser(arguments).options(parsed_options).positional(positional).run(), vm);
     po::notify(vm);
 
-    setup_common(vm);
+    setup_common(vm, desc);
     setup_input_file(vm);
     setup_output_file(vm);
 
@@ -217,6 +220,7 @@ bool CommandChangesetFilter::run() {
     writer.close();
     reader.close();
 
+    show_memory_used();
     m_vout << "Done.\n";
 
     return true;
