@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 http://osmcode.org/osmium
 
-Copyright (C) 2013-2015  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2016  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -28,6 +28,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <boost/program_options.hpp>
 
+#include <osmium/handler/check_order.hpp>
 #include <osmium/index/bool_vector.hpp>
 #include <osmium/io/any_input.hpp>
 #include <osmium/io/any_output.hpp>
@@ -35,31 +36,34 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "command_check_refs.hpp"
 
 bool CommandCheckRefs::setup(const std::vector<std::string>& arguments) {
-    po::options_description cmdline("Allowed options");
-    cmdline.add_options()
+    po::options_description opts_cmd{"COMMAND OPTIONS"};
+    opts_cmd.add_options()
     ("show-ids,i", "Show IDs of missing objects")
     ("check-relations,r", "Also check relations")
     ;
 
-    add_common_options(cmdline);
-    add_single_input_options(cmdline);
+    po::options_description opts_common{add_common_options()};
+    po::options_description opts_input{add_single_input_options()};
 
-    po::options_description hidden("Hidden options");
+    po::options_description hidden;
     hidden.add_options()
     ("input-filename", po::value<std::string>(), "Input file")
     ;
 
-    po::options_description desc("Allowed options");
-    desc.add(cmdline).add(hidden);
+    po::options_description desc;
+    desc.add(opts_cmd).add(opts_common).add(opts_input);
+
+    po::options_description parsed_options;
+    parsed_options.add(desc).add(hidden);
 
     po::positional_options_description positional;
     positional.add("input-filename", 1);
 
     po::variables_map vm;
-    po::store(po::command_line_parser(arguments).options(desc).positional(positional).run(), vm);
+    po::store(po::command_line_parser(arguments).options(parsed_options).positional(positional).run(), vm);
     po::notify(vm);
 
-    setup_common(vm);
+    setup_common(vm, desc);
     setup_input_file(vm);
 
     if (vm.count("show-ids")) {
@@ -86,8 +90,9 @@ class RefCheckHandler : public osmium::handler::Handler {
     osmium::index::BoolVector<osmium::unsigned_object_id_type> m_ways;
 
     std::vector<uint32_t> m_relation_ids;
-    std::set<uint32_t> m_member_relation_ids;
-    std::vector<uint32_t> m_missing_relation_ids;
+    std::vector<std::pair<uint32_t, uint32_t>> m_relation_refs;
+
+    osmium::handler::CheckOrder m_check_order;
 
     uint64_t m_node_count = 0;
     uint64_t m_way_count = 0;
@@ -100,7 +105,6 @@ class RefCheckHandler : public osmium::handler::Handler {
     osmium::util::VerboseOutput& m_vout;
     bool m_show_ids;
     bool m_check_relations;
-    bool m_relations_done = false;
 
 public:
 
@@ -134,28 +138,31 @@ public:
         return m_missing_ways_in_relations;
     }
 
-    uint64_t missing_relations_in_relations() {
-        if (!m_relations_done) {
-            std::sort(m_relation_ids.begin(), m_relation_ids.end());
-
-            std::set_difference(m_member_relation_ids.cbegin(), m_member_relation_ids.cend(),
-                                m_relation_ids.cbegin(), m_relation_ids.cend(),
-                                std::back_inserter(m_missing_relation_ids));
-
-            m_relations_done = true;
-        }
-
-        return m_missing_relation_ids.size();
+    uint64_t missing_relations_in_relations() const {
+        return m_relation_refs.size();
     }
 
-    bool any_errors() {
-        return missing_nodes_in_ways()          > 0 ||
-               missing_nodes_in_relations()     > 0 ||
-               missing_ways_in_relations()      > 0 ||
-               missing_relations_in_relations() > 0;
+    void find_missing_relations() {
+        std::sort(m_relation_refs.begin(), m_relation_refs.end());
+
+        m_relation_refs.erase(
+            std::remove_if(m_relation_refs.begin(), m_relation_refs.end(), [this](std::pair<uint32_t, uint32_t> refs){
+                return std::binary_search(m_relation_ids.begin(), m_relation_ids.end(), refs.first);
+                }),
+                m_relation_refs.end()
+            );
+    }
+
+    bool no_errors() {
+        return missing_nodes_in_ways()          == 0 &&
+               missing_nodes_in_relations()     == 0 &&
+               missing_ways_in_relations()      == 0 &&
+               missing_relations_in_relations() == 0;
     }
 
     void node(const osmium::Node& node) {
+        m_check_order.node(node);
+
         if (m_node_count == 0) {
             m_vout << "Reading nodes...\n";
         }
@@ -165,6 +172,8 @@ public:
     }
 
     void way(const osmium::Way& way) {
+        m_check_order.way(way);
+
         if (m_way_count == 0) {
             m_vout << "Reading ways...\n";
         }
@@ -185,6 +194,8 @@ public:
     }
 
     void relation(const osmium::Relation& relation) {
+        m_check_order.relation(relation);
+
         if (m_relation_count == 0) {
             m_vout << "Reading relations...\n";
         }
@@ -213,7 +224,9 @@ public:
                         }
                         break;
                     case osmium::item_type::relation:
-                        m_member_relation_ids.insert(uint32_t(relation.id()));
+                        if (member.ref() > relation.id() || !std::binary_search(m_relation_ids.begin(), m_relation_ids.end(), uint32_t(member.ref()))) {
+                            m_relation_refs.emplace_back(uint32_t(member.ref()), uint32_t(relation.id()));
+                        }
                         break;
                     default:
                         break;
@@ -223,8 +236,8 @@ public:
     }
 
     void show_missing_relation_ids() {
-        for (auto id : m_missing_relation_ids) {
-            std::cout << "r" << id << " in r\n";
+        for (const auto& refs : m_relation_refs) {
+            std::cout << "r" << refs.first << " in r" << refs.second << "\n";
         }
     }
 
@@ -234,7 +247,22 @@ bool CommandCheckRefs::run() {
     osmium::io::Reader reader(m_input_file);
 
     RefCheckHandler handler(m_vout, m_show_ids, m_check_relations);
-    osmium::apply(reader, handler);
+
+    try {
+        osmium::apply(reader, handler);
+    } catch (osmium::out_of_order_error& e) {
+        std::cerr << e.what() << "\n";
+        std::cerr << "This command expects the input file to be ordered: First nodes in order of ID,\nthen ways in order of ID, then relations in order of ID.\n";
+        exit(1);
+    }
+
+    if (m_check_relations) {
+        handler.find_missing_relations();
+
+        if (m_show_ids) {
+            handler.show_missing_relation_ids();
+        }
+    }
 
     std::cerr << "There are " << handler.node_count() << " nodes, " << handler.way_count() << " ways, and " << handler.relation_count() << " relations in this file.\n";
 
@@ -247,14 +275,12 @@ bool CommandCheckRefs::run() {
         std::cerr << "Nodes in ways missing: " << handler.missing_nodes_in_ways() << "\n";
     }
 
-    if (m_show_ids) {
-        handler.show_missing_relation_ids();
-    }
-
     reader.close();
+
+    show_memory_used();
     m_vout << "Done.\n";
 
-    return !handler.any_errors();
+    return handler.no_errors();
 }
 
 namespace {
