@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 http://osmcode.org/osmium
 
-Copyright (C) 2013-2015  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2016  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -484,31 +484,37 @@ public:
 /*************************************************************************/
 
 bool CommandFileinfo::setup(const std::vector<std::string>& arguments) {
-    po::options_description cmdline("Allowed options");
-    cmdline.add_options()
+    po::options_description opts_cmd{"COMMAND OPTIONS"};
+    opts_cmd.add_options()
     ("extended,e", "Extended output")
     ("get,g", po::value<std::string>(), "Get value")
     ("show-variables,G", "Show variables for --get option")
     ("json,j", "JSON output")
     ;
 
-    add_single_input_options(cmdline);
+    po::options_description opts_common{add_common_options()};
+    po::options_description opts_input{add_single_input_options()};
 
-    po::options_description hidden("Hidden options");
+    po::options_description hidden;
     hidden.add_options()
     ("input-filename", po::value<std::string>(), "Input file")
     ;
 
-    po::options_description desc("Allowed options");
-    desc.add(cmdline).add(hidden);
+    po::options_description desc;
+    desc.add(opts_cmd).add(opts_common).add(opts_input);
+
+    po::options_description parsed_options;
+    parsed_options.add(desc).add(hidden);
 
     po::positional_options_description positional;
     positional.add("input-filename", 1);
 
     po::variables_map vm;
-    po::store(po::command_line_parser(arguments).options(desc).positional(positional).run(), vm);
+    po::store(po::command_line_parser(arguments).options(parsed_options).positional(positional).run(), vm);
     po::notify(vm);
 
+    setup_common(vm, desc);
+
     if (vm.count("extended")) {
         m_extended = true;
     }
@@ -602,6 +608,8 @@ bool CommandFileinfo::run() {
     reader.close();
     output->output();
 
+    m_vout << "Done.\n";
+
     return true;
 }
 
