@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 http://osmcode.org/osmium
 
-Copyright (C) 2013-2015  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2016  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -56,8 +56,8 @@ bool CommandHelp::run() {
     auto commands = CommandFactory::help();
 
     if (m_topic == "help") {
-        std::cout << "Usage: osmium COMMAND [ARG...]\n";
-        std::cout << "       osmium --version\n\nCommands are:\n";
+        std::cout << "Usage: " << synopsis()
+                  << "\n\nCOMMANDS:\n";
 
         // print command names and descriptions in a nice table
         for (const auto& cmd : commands) {
@@ -71,7 +71,8 @@ bool CommandHelp::run() {
                       << "\n";
         }
 
-        std::cout << "\nSee 'osmium help COMMAND' for more information on a specific command." << std::endl;
+        std::cout << "\nUse 'osmium COMMAND -h' for short usage information.\n"
+                     "Use 'osmium help COMMAND' for detailed information on a specific command.\n";
         return true;
     }
 
