@@ -6,7 +6,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 http://osmcode.org/osmium
 
-Copyright (C) 2013-2015  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2016  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -45,6 +45,15 @@ public:
 
     bool run() override final;
 
+    const char* name() const noexcept override final {
+        return "time-filter";
+    }
+
+    const char* synopsis() const noexcept override final {
+        return "osmium time-filter [OPTIONS] OSM-HISTORY-FILE [TIME]\n"
+               "       osmium time-filter [OPTIONS] OSM-HISTORY-FILE FROM-TIME TO-TIME";
+    }
+
 }; // class CommandTimeFilter
 
 
