@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 http://osmcode.org/osmium
 
-Copyright (C) 2013-2015  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2016  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -39,10 +39,14 @@ void with_single_osm_input::setup_input_file(const boost::program_options::varia
     m_input_file = osmium::io::File(m_input_filename, m_input_format);
 }
 
-void with_single_osm_input::add_single_input_options(po::options_description& options) {
+po::options_description with_single_osm_input::add_single_input_options() {
+    po::options_description options{"INPUT OPTIONS"};
+
     options.add_options()
     ("input-format,F", po::value<std::string>(), "Format of input file")
     ;
+
+    return options;
 }
 
 void with_single_osm_input::show_single_input_arguments(osmium::util::VerboseOutput& vout) {
@@ -51,10 +55,10 @@ void with_single_osm_input::show_single_input_arguments(osmium::util::VerboseOut
     vout << "    file format: " << m_input_format << "\n";
 }
 
-void with_multiple_osm_inputs::setup_input_files(const boost::program_options::variables_map& vm) {
+void with_multiple_osm_inputs::setup_input_files(const boost::program_options::variables_map& vm, bool optional) {
     if (vm.count("input-filenames")) {
         m_input_filenames = vm["input-filenames"].as<std::vector<std::string>>();
-    } else {
+    } else if (!optional) {
         m_input_filenames.push_back("-"); // default is stdin
     }
 
@@ -80,10 +84,15 @@ void with_multiple_osm_inputs::setup_input_files(const boost::program_options::v
     }
 }
 
-void with_multiple_osm_inputs::add_multiple_inputs_options(po::options_description& options) {
+
+po::options_description with_multiple_osm_inputs::add_multiple_inputs_options() {
+    po::options_description options{"INPUT OPTIONS"};
+
     options.add_options()
     ("input-format,F", po::value<std::string>(), "Format of input files")
     ;
+
+    return options;
 }
 
 void with_multiple_osm_inputs::show_multiple_inputs_arguments(osmium::util::VerboseOutput& vout) {
@@ -128,15 +137,19 @@ void with_osm_output::setup_output_file(const po::variables_map& vm) {
     m_output_file.check();
 }
 
-void with_osm_output::add_output_options(po::options_description& options) {
+po::options_description with_osm_output::add_output_options() {
+    po::options_description options("OUTPUT OPTIONS");
+
     options.add_options()
+    ("output-format,f", po::value<std::string>(), "Format of output file")
+    ("fsync", "Call fsync after writing file")
     ("generator", po::value<std::string>(), "Generator setting for file header")
     ("output,o", po::value<std::string>(), "Output file")
-    ("output-format,f", po::value<std::string>(), "Format of output file")
-    ("output-header", po::value<std::vector<std::string>>(), "Add output header")
     ("overwrite,O", "Allow existing output file to be overwritten")
-    ("fsync", "Call fsync after writing file")
+    ("output-header", po::value<std::vector<std::string>>(), "Add output header")
     ;
+
+    return options;
 }
 
 void with_osm_output::show_output_arguments(osmium::util::VerboseOutput& vout) {
