@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 http://osmcode.org/osmium
 
-Copyright (C) 2013-2015  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2016  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -29,6 +29,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # include <io.h>
 #endif
 
+#include <osmium/version.hpp>
+
 #include "cmd.hpp"
 
 enum return_code : int {
@@ -76,8 +78,9 @@ int main(int argc, char *argv[]) {
     }
 
     if (command == "version") {
-        std::cout << "osmium version " << OSMIUM_VERSION << "\n"
-                  << "Copyright (C) 2013-2015  Jochen Topf <jochen@topf.org>\n"
+        std::cout << "osmium version " OSMIUM_VERSION "\n"
+                  << "libosmium version " LIBOSMIUM_VERSION_STRING "\n"
+                  << "Copyright (C) 2013-2016  Jochen Topf <jochen@topf.org>\n"
                   << "License: GNU GENERAL PUBLIC LICENSE Version 3 <http://gnu.org/licenses/gpl.html>.\n"
                   << "This is free software: you are free to change and redistribute it.\n"
                   << "There is NO WARRANTY, to the extent permitted by law.\n";
@@ -88,7 +91,7 @@ int main(int argc, char *argv[]) {
     std::unique_ptr<Command> cmd = CommandFactory::instance().create_command(command);
 
     if (!cmd) {
-        std::cerr << "Unknown command '" << command << "'. Try 'osmium help'." << std::endl;
+        std::cerr << "Unknown command or option '" << command << "'. Try 'osmium help'.\n";
         return return_code::fatal;
     }
 
@@ -110,6 +113,8 @@ int main(int argc, char *argv[]) {
         if (cmd->run()) {
             return return_code::okay;
         }
+    } catch (std::bad_alloc& e) {
+        std::cerr << "Out of memory. Read the MEMORY USAGE section of the osmium(1) manpage.\n";
     } catch (std::exception& e) {
         std::cerr << e.what() << "\n";
     }
